autowisp.bui_util module — AutoWISP documentation

# autowisp.bui_util module

## Class Inheritance Diagram

View for displaying FITS images.

autowisp.bui_util._asinh_transform(pixel_values)

  The asinh transform of DS9.

autowisp.bui_util._log_transform(pixel_values, parameter=1000.0)

  Perform the same log-transform as DS9.

autowisp.bui_util._pow_transform(pixel_values, parameter=1000.0)

  Perform the same pow transfom as DS9.

autowisp.bui_util._sinh_transform(pixel_values)

  The sinh transform of DS9.

autowisp.bui_util._sqrt_transform(pixel_values)

  Use square root of the pixel values as intensity.

autowisp.bui_util._square_transform(pixel_values)

  Use the square of the pixel values as intensity.

autowisp.bui_util.encode_fits(fits_fname, values_range, values_transform)

  Display transformed & scaled FITS image to user.

autowisp.bui_util.hex_color(color_tuple)

  Return string of hex color give tuple of 0-1 float values.